=============================
Personal File Utility Library
=============================


.. image:: https://img.shields.io/pypi/v/tjpy_file_util.svg
        :target: https://pypi.python.org/pypi/tjpy_file_util

.. image:: https://img.shields.io/travis/thomasjahoda/tjpy_file_util.svg
        :target: https://travis-ci.org/thomasjahoda/tjpy_file_util

.. image:: https://readthedocs.org/projects/tjpy-file-util/badge/?version=latest
        :target: https://tjpy-file-util.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Utilities related to files


* Free software: MIT license
* Documentation: https://tjpy-file-util.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `thomasjahoda/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/thomasjahoda/cookiecutter
.. _`thomasjahoda/cookiecutter-pypackage`: https://github.com/thomasjahoda/cookiecutter-pypackage
